#
# spec file for package libfsxfs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

Name:           libfsxfs
%define lname	libfsxfs1
Version:        20240501
Release:        1.3
Summary:        Library and tools for accessing the SGI X File System (XFS)
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/libyal/libfsxfs
Source:         https://github.com/libyal/libfsxfs/releases/download/%version/%name-experimental-%version.tar.gz
Source2:        https://github.com/libyal/libfsxfs/releases/download/%version/%name-experimental-%version.tar.gz.asc
Source3:        %name.keyring
BuildRequires:  %python_module devel
BuildRequires:  %python_module setuptools
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libbfio) >= 20240414
BuildRequires:  pkgconfig(libcdata) >= 20240414
BuildRequires:  pkgconfig(libcerror) >= 20240413
BuildRequires:  pkgconfig(libcfile) >= 20240414
BuildRequires:  pkgconfig(libclocale) >= 20240414
BuildRequires:  pkgconfig(libcnotify) >= 20240414
BuildRequires:  pkgconfig(libcpath) >= 20240414
BuildRequires:  pkgconfig(libcsplit) >= 20240414
BuildRequires:  pkgconfig(libcthreads) >= 20240413
BuildRequires:  pkgconfig(libfcache) >= 20240414
BuildRequires:  pkgconfig(libfcrypto) >= 20240414
BuildRequires:  pkgconfig(libfdata) >= 20240415
BuildRequires:  pkgconfig(libfdatetime) >= 20240415
BuildRequires:  pkgconfig(libfguid) >= 20240415
BuildRequires:  pkgconfig(libhmac) >= 20240417
BuildRequires:  pkgconfig(libuna) >= 20240414
BuildRequires:  pkgconfig(python3)
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
libfsxfs is a library to access the SGI X File System (XFS).

Part of the libyal family of libraries.

%package -n %lname
Summary:        Library for accessing the SGI X File System (XFS)
Group:          System/Libraries

%description -n %lname
libfsxfs is a library to access the SGI X File System (XFS).

Part of the libyal family of libraries.

%package devel
Summary:        Development files for libfsxfs
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
libfsxfs is a library to access the SGI X File System (XFS).

This subpackage contains libraries and header files for developing
applications that want to make use of libfsxfs.

%package tools
Summary:        Utilities to inspect SGI X File Systems (XFS)
Group:          Productivity/File utilities

%description tools
This subpackage provides the utilities from libfsxfs, which allows for
reading SGI X File Systems (XFS).

%prep
%autosetup -p1

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type --enable-python \
	PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv "%_builddir/rt"/* %buildroot/
find "%buildroot" -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING*
%_libdir/libfsxfs.so.*

%files -n %name-devel
%_includedir/*
%_libdir/*.so
%_libdir/pkgconfig/*.pc
%_mandir/man3/*.3*

%files -n %name-tools
%_bindir/fsxfs*
%_mandir/man1/fsxfs*

%files %python_files
%python_sitearch/py*.so

%changelog
* Wed May  1 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240501
  * No user-visible changes
* Thu Feb 22 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240222
  * No user-visible changes
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Use python-setuptools for python distutils backport
  gh#libyal/libbde#68
* Sat Nov 25 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231124
  * Improved Python Unicode handling
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Tue Aug 30 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220829
  * Improvements to extended attribute support
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update build requirement on libcfile
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Thu Jul  7 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220706
  * Unspecified updates to device number support
* Sat May 28 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220528
  * Improved extended attributes support.
  * Unspecified updates to Python bindings.
* Fri Jan 21 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220113
  * Improved xattr support. Tool updates.
* Sun Nov 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210726
  * Improved extended attributes support
* Sun May 16 2021 Jan Engelhardt <jengelh@inai.de>
- Initial package for build.opensuse.org
  (version 20210507/commit e4ac16fe)
- Add system-libs.patch
